pygerber.parser.pillow.apertures.custom module
==============================================

.. automodule:: pygerber.parser.pillow.apertures.custom
   :members:
   :undoc-members:
   :show-inheritance:
